Agent

Struct Agent 

#[repr(C)]
pub struct Agent { pub id: u64, pub profession: u32, pub is_elite: u32, pub toughness: i16, pub concentration: i16, pub healing: i16, pub hitbox_width: u16, pub condition: i16, pub hitbox_height: u16, pub name: [i8; 64], }
An EVTC agent.

Could be a player, enemy, minion or other.

If is_elite == 0xffffffff and upper half of prof == 0xffff, the agent is a gadget with a pseudo id as lower half of prof (volatile id). If is_elite == 0xffffffff and upper half of prof != 0xffff, the agent is an NPC with species id as lower half of prof (reliable id). If is_elite != 0xffffffff, the agent is a player with Profession as prof and Elite Specialization as is_elite.

Gadgets do not have true ids and are generated through a combination of gadget parameters. They will collide with NPCs and should be treated separately.

Fields

id: u64

Unique agent id as assigned by ArcDPS.

profession: u32

Profession for player agents

is_elite: u32

Elite specialization for player agents.

toughness: i16

Normalized Toughness attribute of the agent.

concentration: i16

Normalized Concentration attribute of the agent.

healing: i16

Normalized Healing attribute of the agent.

hitbox_width: u16

Hitbox width of the agent.

condition: i16

Normalized Condition Damage attribute of the agent.

hitbox_height: u16

Hitbox height of the agent.

name: [i8; 64]

Name information for the agent.

For players this is a combo string containing the character name, account name and subgroup.

Implementations



impl Agent

pub const NAME_SIZE: usize = 64

Size of the name combo string.

pub const fn kind(&self) -> AgentKind

Determines the kind of agent.