Struct Agent
#[repr(C)]pub struct Agent {
pub id: u64,
pub profession: u32,
pub is_elite: u32,
pub toughness: i16,
pub concentration: i16,
pub healing: i16,
pub hitbox_width: u16,
pub condition: i16,
pub hitbox_height: u16,
pub name: [i8; 64],
}Expand description
An EVTC agent.
Could be a player, enemy, minion or other.
If is_elite == 0xffffffff and upper half of prof == 0xffff, the agent is a gadget with a pseudo id as lower half of prof (volatile id).
If is_elite == 0xffffffff and upper half of prof != 0xffff, the agent is an NPC with species id as lower half of prof (reliable id).
If is_elite != 0xffffffff, the agent is a player with Profession as prof and Elite Specialization as is_elite.
Gadgets do not have true ids and are generated through a combination of gadget parameters. They will collide with NPCs and should be treated separately.
Fields
id: u64Unique agent id as assigned by ArcDPS.
profession: u32Profession for player agents
is_elite: u32Elite specialization for player agents.
toughness: i16Normalized Toughness attribute of the agent.
concentration: i16Normalized Concentration attribute of the agent.
healing: i16Normalized Healing attribute of the agent.
hitbox_width: u16Hitbox width of the agent.
condition: i16Normalized Condition Damage attribute of the agent.
hitbox_height: u16Hitbox height of the agent.
name: [i8; 64]Name information for the agent.
For players this is a combo string containing the character name, account name and subgroup.